@@ -88,13 +88,18 @@ Tuner = R6Class("Tuner",
     #' @param packages (`character()`)\cr
     #' Set of required packages. Note that these packages will be loaded via
     #' [requireNamespace()], and are not attached.
-    initialize = function(param_set, param_classes, properties, packages = character()) {
+    #'
+    #' @param man (`character(1)`)\cr
+    #'   String in the format `[pkg]::[topic]` pointing to a manual page for this object.
+    #'   The referenced help package can be opened via method `$help()`.
+    initialize = function(param_set, param_classes, properties, packages = character(), man = NA_character_) {
       private$.param_set = assert_param_set(param_set)
       private$.param_classes = assert_subset(param_classes,
         c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct", "ParamUty"))
       # has to have at least multi-crit or single-crit property
       private$.properties = assert_subset(properties, bbotk_reflections$optimizer_properties, empty.ok = FALSE)
       private$.packages = union("mlr3tuning", assert_character(packages, any.missing = FALSE, min.chars = 1L))
+      private$.man = assert_string(man, na.ok = TRUE)
 
       check_packages_installed(self$packages,
         msg = sprintf("Package '%%s' required but not installed for Tuner '%s'", format(self)))
@@ -117,6 +122,12 @@ Tuner = R6Class("Tuner",
       catf(str_indent("* Packages:", self$packages))
     },
 
+    #' @description
+    #' Opens the corresponding help page referenced by field `$man`.
+    help = function() {
+      open_help(self$man)
+    },
+
     #' @description
     #' Performs the tuning on a [TuningInstanceSingleCrit] or
     #' [TuningInstanceMultiCrit] until termination.
@@ -167,6 +178,14 @@ Tuner = R6Class("Tuner",
         stop("$packages is read-only.")
       }
       private$.packages
+    },
+
+    #' @field man (`character()`).
+    man = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.man)) {
+        stop("$man is read-only.")
+      }
+      private$.man
     }
   ),
 
@@ -181,6 +200,7 @@ Tuner = R6Class("Tuner",
     .param_set = NULL,
     .param_classes = NULL,
     .properties = NULL,
-    .packages = NULL
+    .packages = NULL,
+    .man = NULL
   )
 )
