@@ -33,10 +33,10 @@
 #' \dontrun{
 #' # retrieve task
 #' task = tsk("pima")
-#' 
+#'
 #' # load learner and set search space
 #' learner = lrn("classif.rpart", cp = to_tune(1e-04, 1e-1, logscale = TRUE))
-#' 
+#'
 #' # hyperparameter tuning on the pima indians diabetes data set
 #' instance = tune(
 #'   method = "nloptr",
@@ -49,10 +49,10 @@
 #'
 #' # best performing hyperparameter configuration
 #' instance$result
-#' 
+#'
 #' # all evaluated hyperparameter configuration
 #' as.data.table(instance$archive)
-#' 
+#'
 #' # fit final model on complete data set
 #' learner$param_set$values = instance$result_learner_param_vals
 #' learner$train(task)
@@ -67,6 +67,7 @@ TunerNLoptr = R6Class("TunerNLoptr",
       super$initialize(
         optimizer = OptimizerNLoptr$new()
       )
+      private$.man = "mlr3tuning::mlr_tuners_nloptr"
     }
   )
 )
